@@ -216,7 +216,13 @@ def get_contrib_pysite_deps():
 
     # twisted[tls], see setup.py for %twisted_version%
     result.extend(
-        ["pyopenssl >= 16.0.0", "service_identity >= 18.1.0", "idna >= 0.6, != 2.3"]
+        [
+            # pyopenssl depends on it, use RUST-less version
+            "cryptography >= 3.3, < 35.0.0",
+            "pyopenssl >= 16.0.0",
+            "service_identity >= 18.1.0",
+            "idna >= 0.6, != 2.3",
+        ]
     )
 
     if "windows" in sys_type:
