@@ -20,7 +20,7 @@ from platformio.project.config import ProjectConfig
 class ToolPackageManager(BasePackageManager):  # pylint: disable=too-many-ancestors
     def __init__(self, package_dir=None):
         if not package_dir:
-            package_dir = ProjectConfig.get_instance().get_optional_dir("packages")
+            package_dir = ProjectConfig.get_instance().get("platformio", "packages_dir")
         super(ToolPackageManager, self).__init__(PackageType.TOOL, package_dir)
 
     @property
